==> haskell-wai-logger-2.5.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-9vR97ZcxaPV1yU5B42GMTb
key:                  wai-logger-2.5.0-9vR97ZcxaPV1yU5B42GMTb
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  85d3886e01034a30a3804ab59511de62
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-9vR97ZcxaPV1yU5B42GMTb
depends:
    base-4.16.4.0 byteorder-1.0.4-CJPSLP7rc8u3oRjd7vzP2g
    bytestring-0.11.4.0 fast-logger-3.1.2-HRfTVNlQd84GlAKlGtHEjK
    http-types-0.12.4-IK3jZB6tw6k2KWf3RXsYsl
    network-3.1.4.0-IMH4i2bhORraAL0d8HxBg
    wai-3.2.4-7wDTXFXmYYd6TVujdrRhKq

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.5.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-logger
version:              2.5.0
visibility:           public
id:                   wai-logger-2.5.0-BrP6j2e10IHagpCZVJaA7
key:                  wai-logger-2.5.0-BrP6j2e10IHagpCZVJaA7
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI(Web Application Interface)
category:             Web, Yesod
abi:                  f437ae2b26bbf962735bef321cb44f6a
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-logger-2.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-logger-2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.5.0-BrP6j2e10IHagpCZVJaA7
depends:
    base-4.16.4.0 byteorder-1.0.4-CJPSLP7rc8u3oRjd7vzP2g
    bytestring-0.11.4.0 fast-logger-3.1.2-40jgXSfrrv1Lb3em5mDBkP
    http-types-0.12.4-K1BiuBnIehk6RPUQXWJDEB
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    wai-3.2.4-Izl5rpe0LrhAt7zW5A5dt7

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
